paulbutcher.ring-lambda-adapter


handle-requestclj

(handle-request app is os)

Example usage:

(ns my-application.lambda
  (:gen-class :implements
              [com.amazonaws.services.lambda.runtime.RequestStreamHandler])
  (:require [paulbutcher.ring-lambda-adapter :refer [handle-request]]))

(defn -handleRequest [_ is os _context] (handle-request my-application/app is os))
Example usage:

```clojure
(ns my-application.lambda
  (:gen-class :implements
              [com.amazonaws.services.lambda.runtime.RequestStreamHandler])
  (:require [paulbutcher.ring-lambda-adapter :refer [handle-request]]))

(defn -handleRequest [_ is os _context] (handle-request my-application/app is os))
```
sourceraw docstring

lambda-request->ring-requestclj

(lambda-request->ring-request request)

Given a Lambda function URL request, returns a Ring request map.

Function URL request format: https://docs.aws.amazon.com/lambda/latest/dg/urls-invocation.html#urls-request-payload

Ring request spec: https://github.com/ring-clojure/ring/blob/master/SPEC.md#14-request-maps

Given a Lambda function URL request, returns a Ring request map.

Function URL request format:
https://docs.aws.amazon.com/lambda/latest/dg/urls-invocation.html#urls-request-payload

Ring request spec:
https://github.com/ring-clojure/ring/blob/master/SPEC.md#14-request-maps
sourceraw docstring

ring-response->lambda-responseclj

(ring-response->lambda-response response)

Given a Ring response map, returns a Lambda function URL response.

Function URL response format: https://docs.aws.amazon.com/lambda/latest/dg/urls-invocation.html#urls-response-payload Ring response spec: https://github.com/ring-clojure/ring/blob/master/SPEC.md#15-response-maps

Given a Ring response map, returns a Lambda function URL response.

Function URL response format:
https://docs.aws.amazon.com/lambda/latest/dg/urls-invocation.html#urls-response-payload
Ring response spec:
https://github.com/ring-clojure/ring/blob/master/SPEC.md#15-response-maps
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries